==> haskell-ghcide-2.1.0.0-100-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-ghcide.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 ghcide
version:              2.1.0.0
visibility:           public
id:                   ghcide-2.1.0.0-FnivsoqaY804ocwiGSGs4S
key:                  ghcide-2.1.0.0-FnivsoqaY804ocwiGSGs4S
license:              Apache-2.0
copyright:            Digital Asset and Ghcide contributors 2018-2020
maintainer:           Ghcide contributors
author:               Digital Asset and Ghcide contributors
homepage:
    https://github.com/haskell/haskell-language-server/tree/master/ghcide#readme

synopsis:             The core of an IDE
description:          A library for building Haskell IDE'\''s on top of the GHC API.
category:             Development
abi:                  12a8d112e6509d690fd521d3c1ea86ee
exposed:              True
exposed-modules:
    Control.Concurrent.Strict Development.IDE
    Development.IDE.Core.Actions Development.IDE.Core.Compile
    Development.IDE.Core.Debouncer Development.IDE.Core.FileStore
    Development.IDE.Core.FileUtils
    Development.IDE.Core.IdeConfiguration
    Development.IDE.Core.OfInterest Development.IDE.Core.PluginUtils
    Development.IDE.Core.PositionMapping
    Development.IDE.Core.Preprocessor
    Development.IDE.Core.ProgressReporting
    Development.IDE.Core.RuleTypes Development.IDE.Core.Rules
    Development.IDE.Core.Service Development.IDE.Core.Shake
    Development.IDE.Core.Tracing Development.IDE.Core.UseStale
    Development.IDE.GHC.Compat Development.IDE.GHC.Compat.Core
    Development.IDE.GHC.Compat.Env Development.IDE.GHC.Compat.Iface
    Development.IDE.GHC.Compat.Logger
    Development.IDE.GHC.Compat.Outputable
    Development.IDE.GHC.Compat.Parser
    Development.IDE.GHC.Compat.Plugins Development.IDE.GHC.Compat.Units
    Development.IDE.GHC.Compat.Util Development.IDE.GHC.CoreFile
    Development.IDE.GHC.Error Development.IDE.GHC.Orphans
    Development.IDE.GHC.Util
    Development.IDE.Import.DependencyInformation
    Development.IDE.Import.FindImports
    Development.IDE.LSP.HoverDefinition
    Development.IDE.LSP.LanguageServer
    Development.IDE.LSP.Notifications Development.IDE.LSP.Outline
    Development.IDE.LSP.Server Development.IDE.Main
    Development.IDE.Main.HeapStats Development.IDE.Monitoring.EKG
    Development.IDE.Monitoring.OpenTelemetry Development.IDE.Plugin
    Development.IDE.Plugin.Completions
    Development.IDE.Plugin.Completions.Types Development.IDE.Plugin.HLS
    Development.IDE.Plugin.HLS.GhcIde Development.IDE.Plugin.Test
    Development.IDE.Plugin.TypeLenses Development.IDE.Session
    Development.IDE.Spans.AtPoint Development.IDE.Spans.Common
    Development.IDE.Spans.Documentation
    Development.IDE.Spans.LocalBindings Development.IDE.Spans.Pragmas
    Development.IDE.Types.Diagnostics Development.IDE.Types.Exports
    Development.IDE.Types.HscEnvEq Development.IDE.Types.KnownTargets
    Development.IDE.Types.Location Development.IDE.Types.Monitoring
    Development.IDE.Types.Options Development.IDE.Types.Shake
    Generics.SYB.GHC Text.Fuzzy.Parallel

hidden-modules:
    Development.IDE.Core.FileExists Development.IDE.GHC.CPP
    Development.IDE.GHC.Warnings
    Development.IDE.Plugin.Completions.Logic
    Development.IDE.Session.VersionCheck Development.IDE.Types.Action

import-dirs:          /usr/lib/ghc-9.6.6/site-local/ghcide-2.1.0.0
library-dirs:         /usr/lib/ghc-9.6.6/site-local/ghcide-2.1.0.0
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/ghcide-2.1.0.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-ghcide
hs-libraries:         HSghcide-2.1.0.0-FnivsoqaY804ocwiGSGs4S
depends:
    Diff-0.5-yETzKh0qtuDUuvJdOns8X Glob-0.10.2-AkNemguOk3X5pWzckA4YZJ
    aeson-2.1.2.1-GojnAvr1Jep10WUNi5H1Pi
    aeson-pretty-0.8.10-CQgtmRgYKKmDAUdx88Og8E array-0.5.6.0
    async-2.2.5-1Z88VuXAsSjFYCStMD3XFv base-4.18.2.1
    base16-bytestring-1.0.2.0-Dwd5n4mSUH32rjuqPFOreR binary-0.8.9.1
    bytestring-0.11.5.3 case-insensitive-1.2.1.0-3fPl2hvou1nDiCO1iE2i5z
    co-log-core-0.3.2.5-F1cXOLptdAs7fL36TTB1WQ containers-0.6.7
    cryptohash-sha1-0.11.101.0-BjsOb6FJgTCBp7n5ZEroI4
    data-default-0.7.1.3-EtVHsfbH5oIpJ9umzYHUz deepseq-1.4.8.1
    dependent-map-0.4.0.1-J2tLrupnxeh9MjbAVDyiTR
    dependent-sum-0.7.2.0-HfTA5YxTWEXGwqGB9upS0D directory-1.3.8.5
    dlist-1.0-B7D1vsARFiIHVaGk5CGbYO
    enummapset-0.7.3.0-2dh8JkjpSa6IrHg1zYWgj5 exceptions-0.10.7
    extra-1.7.16-3o8MjPiNQTlLg74BSenHLy filepath-1.4.300.1
    fingertree-0.1.6.2-1PgNfRTFIgw8zTTFVYZdaB
    focus-1.0.3.2-dqVNbqCJwxApDYKekKDIO ghc-9.6.6 ghc-boot-9.6.6
    ghc-boot-th-9.6.6 ghc-check-0.5.0.8-ArWCdX3lBLiC75JtLiDFT0
    ghc-paths-0.1.0.12-JSGGj7CcxjZ2Iy0LlOG5cZ
    ghc-trace-events-0.1.2.10-H26I0MYftT2GE85bySiIsN
    haddock-library-1.11.0-1hjqyuYC4gZ5fYUMDdPuds
    hashable-1.4.7.0-DKTv0aQgcZmBEMi2BPTV4Z
    hie-bios-0.12.0-1PoJuI5561m6r5BNOLpFUV
    hie-compat-0.3.1.2-37lTPgU0jdr1Ufn5QvEKoZ
    hiedb-0.4.3.0-In3a35d9RZoBKNa9hffqgQ
    hls-graph-2.1.0.0-2K7OAPbw31L8NzoSrWGIDe
    hls-plugin-api-2.1.0.0-DLt74c0m6zn5iIl3F9hXDn
    implicit-hie-0.1.4.0-9puXQ5ClVVI6Ed4F3hu9IY
    implicit-hie-cradle-0.5.0.1-3VQ2bjHNKdm1spBpIZqPHV
    lens-5.3.3-HAYf6JaG0qX5o8D7xn9NgM
    list-t-1.0.5.7-AhA7x2MdeKdKv2uigYKj0T
    lsp-2.1.0.0-FDkJ3hOfaOyD0G3xXwdyeX
    lsp-types-2.0.1.0-KsWoulY9wwoKMSLEqbLHCK mtl-2.3.1
    opentelemetry-0.8.0-78VWkW9YLqi7UDSXGjjBFN
    optparse-applicative-0.18.1.0-AbA9pm273O8LTotNJ1t1CE
    parallel-3.2.2.0-4GFGhbl8Ae06nPoqdIyBUD
    prettyprinter-1.7.1-KtmqmFkRxIvL2FcrwTTeTo
    prettyprinter-ansi-terminal-1.1.3-LcajTeMLJmqJgHikO6kzwA
    random-1.2.1.3-6SxnlPLCqt06GlpnYLfwZm
    regex-tdfa-1.3.2.5-ATqtlBuPETHJOcVIKuiav2
    row-types-1.0.1.2-FuMsfCVBkwF72uFC405BUE
    safe-exceptions-0.1.7.4-77vNmGqKu2OFQzf0vTZZHI
    sorted-list-0.2.3.1-FHWpn5IT6v0L85Ofir7qig
    sqlite-simple-0.4.19.0-J9daIpu6jyNBDZIdTcHL6M stm-2.5.1.0
    stm-containers-1.2.1.1-Hz65IINTWZ7BOmg5g07dNl
    syb-0.7.3-7GPFF4ffw0kLXaCjDkD2wt text-2.0.2
    text-rope-0.3-Gq8oRIBjiYqAbKRkuHVfVA time-1.12.2
    transformers-0.6.1.0 unix-2.8.4.0
    unliftio-0.2.25.1-IdlKKcTSqjp7zAgGJLE7Xd
    unliftio-core-0.2.1.0-6sOpIonHj8t5wIbPhWbPHY
    unordered-containers-0.2.20.1-50qrTxmoJy9AxZ7OdMnycu
    vector-0.13.2.0-L5lYsWFgdBEAgjlr9nnpMP

haddock-interfaces:   /usr/share/doc/haskell-ghcide/html/ghcide.haddock
haddock-html:         /usr/share/doc/haskell-ghcide/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-ghcide-2.1.0.0-102-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-ghcide.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 ghcide
version:              2.1.0.0
visibility:           public
id:                   ghcide-2.1.0.0-FpGXYcNEFHuE24CSyfyNdp
key:                  ghcide-2.1.0.0-FpGXYcNEFHuE24CSyfyNdp
license:              Apache-2.0
copyright:            Digital Asset and Ghcide contributors 2018-2020
maintainer:           Ghcide contributors
author:               Digital Asset and Ghcide contributors
homepage:
    https://github.com/haskell/haskell-language-server/tree/master/ghcide#readme

synopsis:             The core of an IDE
description:          A library for building Haskell IDE'\''s on top of the GHC API.
category:             Development
abi:                  22e8587fc76f1dad0921102965c099eb
exposed:              True
exposed-modules:
    Control.Concurrent.Strict Development.IDE
    Development.IDE.Core.Actions Development.IDE.Core.Compile
    Development.IDE.Core.Debouncer Development.IDE.Core.FileStore
    Development.IDE.Core.FileUtils
    Development.IDE.Core.IdeConfiguration
    Development.IDE.Core.OfInterest Development.IDE.Core.PluginUtils
    Development.IDE.Core.PositionMapping
    Development.IDE.Core.Preprocessor
    Development.IDE.Core.ProgressReporting
    Development.IDE.Core.RuleTypes Development.IDE.Core.Rules
    Development.IDE.Core.Service Development.IDE.Core.Shake
    Development.IDE.Core.Tracing Development.IDE.Core.UseStale
    Development.IDE.GHC.Compat Development.IDE.GHC.Compat.Core
    Development.IDE.GHC.Compat.Env Development.IDE.GHC.Compat.Iface
    Development.IDE.GHC.Compat.Logger
    Development.IDE.GHC.Compat.Outputable
    Development.IDE.GHC.Compat.Parser
    Development.IDE.GHC.Compat.Plugins Development.IDE.GHC.Compat.Units
    Development.IDE.GHC.Compat.Util Development.IDE.GHC.CoreFile
    Development.IDE.GHC.Error Development.IDE.GHC.Orphans
    Development.IDE.GHC.Util
    Development.IDE.Import.DependencyInformation
    Development.IDE.Import.FindImports
    Development.IDE.LSP.HoverDefinition
    Development.IDE.LSP.LanguageServer
    Development.IDE.LSP.Notifications Development.IDE.LSP.Outline
    Development.IDE.LSP.Server Development.IDE.Main
    Development.IDE.Main.HeapStats Development.IDE.Monitoring.EKG
    Development.IDE.Monitoring.OpenTelemetry Development.IDE.Plugin
    Development.IDE.Plugin.Completions
    Development.IDE.Plugin.Completions.Types Development.IDE.Plugin.HLS
    Development.IDE.Plugin.HLS.GhcIde Development.IDE.Plugin.Test
    Development.IDE.Plugin.TypeLenses Development.IDE.Session
    Development.IDE.Spans.AtPoint Development.IDE.Spans.Common
    Development.IDE.Spans.Documentation
    Development.IDE.Spans.LocalBindings Development.IDE.Spans.Pragmas
    Development.IDE.Types.Diagnostics Development.IDE.Types.Exports
    Development.IDE.Types.HscEnvEq Development.IDE.Types.KnownTargets
    Development.IDE.Types.Location Development.IDE.Types.Monitoring
    Development.IDE.Types.Options Development.IDE.Types.Shake
    Generics.SYB.GHC Text.Fuzzy.Parallel

hidden-modules:
    Development.IDE.Core.FileExists Development.IDE.GHC.CPP
    Development.IDE.GHC.Warnings
    Development.IDE.Plugin.Completions.Logic
    Development.IDE.Session.VersionCheck Development.IDE.Types.Action

import-dirs:          /usr/lib/ghc-9.6.6/site-local/ghcide-2.1.0.0
library-dirs:         /usr/lib/ghc-9.6.6/site-local/ghcide-2.1.0.0
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/ghcide-2.1.0.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-ghcide
hs-libraries:         HSghcide-2.1.0.0-FpGXYcNEFHuE24CSyfyNdp
depends:
    Diff-0.5-8gj4s2z6jOl7FPRCGftIez Glob-0.10.2-5kv8V0ytwO85Bs2S1wsFnS
    aeson-2.1.2.1-CpIoOLI7lIpJkSqSOmDN9y
    aeson-pretty-0.8.10-BjxB783FV8e8YPhrNbMs4J array-0.5.6.0
    async-2.2.5-6z3frWRfGJJLLgOv3gEskc base-4.18.2.1
    base16-bytestring-1.0.2.0-ARBAmNNbyxLEDoUwDjra0R binary-0.8.9.1
    bytestring-0.11.5.3 case-insensitive-1.2.1.0-KNymwxzPyypAOJSQGx0ioI
    co-log-core-0.3.2.5-3ZAPJG8B8UQLXQ3UK4qwOj containers-0.6.7
    cryptohash-sha1-0.11.101.0-I0vIPZWrlt0Gys06a7iUtx
    data-default-0.7.1.3-EtVHsfbH5oIpJ9umzYHUz deepseq-1.4.8.1
    dependent-map-0.4.0.1-3I2hbCX6d3o6NTbANPBueg
    dependent-sum-0.7.2.0-qEijTnHeq8F65XWeXqYVy directory-1.3.8.5
    dlist-1.0-B7D1vsARFiIHVaGk5CGbYO
    enummapset-0.7.3.0-9IIdu7sihJJI8JszAnk4X4 exceptions-0.10.7
    extra-1.7.16-IkudFHstV64EKMSGT8IWWb filepath-1.4.300.1
    fingertree-0.1.6.2-9C2f3k75hFcCEg0BQd5B9P
    focus-1.0.3.2-K7eYaaN3rLJIOKNkem96pr ghc-9.6.6 ghc-boot-9.6.6
    ghc-boot-th-9.6.6 ghc-check-0.5.0.8-EfwdDqh52DcE1vfSzPB33A
    ghc-paths-0.1.0.12-JSGGj7CcxjZ2Iy0LlOG5cZ
    ghc-trace-events-0.1.2.10-H26I0MYftT2GE85bySiIsN
    haddock-library-1.11.0-JOkLgY4aTJqDKESNOwDEMb
    hashable-1.4.7.0-1GSULm1uRgQBgX6mu6tvYD
    hie-bios-0.12.0-FNEim36epU8Dn9Th1xNmRS
    hie-compat-0.3.1.2-37lTPgU0jdr1Ufn5QvEKoZ
    hiedb-0.4.3.0-JrTc7LV9Ba920uOneyacpK
    hls-graph-2.1.0.0-LgEicARMXCt6QmF6Vp3LRx
    hls-plugin-api-2.1.0.0-BfiKLSupfw45UdhJj6iHuY
    implicit-hie-0.1.4.0-6gHANNr4w6g2WMvlW7rWZC
    implicit-hie-cradle-0.5.0.1-J3a6bj5Lnow490wWhNiiGK
    lens-5.3.3-GI3kNGpcyiIBMdla72MFoB
    list-t-1.0.5.7-FrIBwXDu8V5JPdGMNO7zz5
    lsp-2.1.0.0-jiZ0SP1Jku9ft66mbKdaK
    lsp-types-2.0.1.0-16awFyiKGg1Iy6lHArG7S3 mtl-2.3.1
    opentelemetry-0.8.0-Dm3Gp7158KP4xW3BJICjGm
    optparse-applicative-0.18.1.0-BnGHnrTdK6d4c7MmJxSY0G
    parallel-3.2.2.0-4GFGhbl8Ae06nPoqdIyBUD
    prettyprinter-1.7.1-BsaWeUw0po1KNye7GKTBJ
    prettyprinter-ansi-terminal-1.1.3-8bIrDelGjXzHJngnsc4lAf
    random-1.2.1.3-LIVoFEqTBeMDojO1AYDBLj
    regex-tdfa-1.3.2.5-EWGvfiHhNcof6jXGuIJ2K
    row-types-1.0.1.2-Lk5eej2rV6aHvk9G3xl6hA
    safe-exceptions-0.1.7.4-77vNmGqKu2OFQzf0vTZZHI
    sorted-list-0.2.3.1-6IpFap5Nw7p5zl2rc6CVd6
    sqlite-simple-0.4.19.0-5vfJm6muwz0GpIPQ7iB7ck stm-2.5.1.0
    stm-containers-1.2.1.1-ERO4CbZuQhYK0vXacIine9
    syb-0.7.3-MvqtDDcT2PHyhdKWhEKAp text-2.0.2
    text-rope-0.3-7UnKSGc2q389N6WPFXjNKl time-1.12.2
    transformers-0.6.1.0 unix-2.8.4.0
    unliftio-0.2.25.1-6Q6KWrgvoh1DxBXv7luml2
    unliftio-core-0.2.1.0-6sOpIonHj8t5wIbPhWbPHY
    unordered-containers-0.2.20.1-L0jiELAFLwP1g4FZscm3B5
    vector-0.13.2.0-eGaPlIkScLKlfBYQuI3vH

haddock-interfaces:   /usr/share/doc/haskell-ghcide/html/ghcide.haddock
haddock-html:         /usr/share/doc/haskell-ghcide/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
